@@ -6,7 +6,7 @@
 Custom types for postgres & sqlalchemy
 """
 
-from sqlalchemy import TIMESTAMP
+from sqlalchemy import TIMESTAMP, text
 from sqlalchemy.dialects.postgresql.ranges import RangeOperators
 from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.sql import sqltypes
@@ -127,7 +127,7 @@ def pg_exists(conn, name):
     Does a postgres object exist?
     :rtype bool
     """
-    return conn.execute("SELECT to_regclass(%s)", name).scalar() is not None
+    return conn.execute(text(f"SELECT to_regclass('{name}')")).scalar() is not None
 
 
 def pg_column_exists(conn, table, column):
@@ -135,15 +135,15 @@ def pg_column_exists(conn, table, column):
     Does a postgres object exist?
     :rtype bool
     """
-    return conn.execute("""
+    return conn.execute(text(f"""
                         SELECT 1 FROM pg_attribute
-                        WHERE attrelid = to_regclass(%s)
-                        AND attname = %s
+                        WHERE attrelid = to_regclass('{table}')
+                        AND attname = '{column}'
                         AND NOT attisdropped
-                        """, table, column).scalar() is not None
+                        """)).scalar() is not None
 
 
-def escape_pg_identifier(engine, name):
+def escape_pg_identifier(conn, name):
     """
     Escape identifiers (tables, fields, roles, etc) for inclusion in SQL statements.
 
@@ -155,4 +155,4 @@ def escape_pg_identifier(engine, name):
     # New (2.7+) versions of psycopg2 have function: extensions.quote_ident()
     # But it's too bleeding edge right now. We'll ask the server to escape instead, as
     # these are not performance sensitive.
-    return engine.execute("select quote_ident(%s)", name).scalar()
+    return conn.execute(text(f"select quote_ident('{name}')")).scalar()
