@@ -21,7 +21,19 @@ from datacube.model import Product
 from datacube.model import Range
 
 from datacube import Datacube
-from .search_utils import assume_utc, _cli_csv_search, _csv_search_raw, _load_product_query
+from .search_utils import _cli_csv_search, _csv_search_raw, _load_product_query
+from datacube.utils.dates import tz_as_utc
+
+
+def test_search_by_metadata(index: Index, ls8_eo3_product, wo_eo3_product):
+    lds = list(index.products.search_by_metadata({"properties": {"product_family": "ard"}}))
+    assert len(lds) == 0
+    lds = list(index.products.search_by_metadata({"properties": {"odc:product_family": "ard"}}))
+    assert len(lds) == 1
+    lds = list(index.products.search_by_metadata({"properties": {"platform": "landsat-8"}}))
+    assert len(lds) == 0
+    lds = list(index.products.search_by_metadata({"properties": {"eo:platform": "landsat-8"}}))
+    assert len(lds) == 1
 
 
 def test_search_dataset_equals_eo3(index: Index, ls8_eo3_dataset: Dataset):
@@ -199,10 +211,12 @@ def test_search_by_product_eo3(index: Index,
     assert len(products) == 1
     [dataset] = products[base_eo3_product_doc["name"]]
     assert dataset.id == wo_eo3_dataset.id
+    assert dataset.is_eo3
+    assert dataset.type == dataset.product
 
 
 def test_search_limit_eo3(index, ls8_eo3_dataset, ls8_eo3_dataset2, wo_eo3_dataset):
-    prod = ls8_eo3_dataset.type.name
+    prod = ls8_eo3_dataset.product.name
     datasets = list(index.datasets.search(product=prod))
     assert len(datasets) == 2
     datasets = list(index.datasets.search(limit=1, product=prod))
@@ -272,7 +286,7 @@ def test_search_or_expressions_eo3(index: Index,
 
     # OR both products: return all
     datasets = index.datasets.search_eager(
-        product=[ls8_eo3_dataset.type.name, wo_eo3_dataset.type.name]
+        product=[ls8_eo3_dataset.product.name, wo_eo3_dataset.product.name]
     )
     assert len(datasets) == 3
     ids = set(dataset.id for dataset in datasets)
@@ -294,7 +308,7 @@ def test_search_or_expressions_eo3(index: Index,
 
     # Redundant ORs should have no effect.
     datasets = index.datasets.search_eager(
-        product=[wo_eo3_dataset.type.name, wo_eo3_dataset.type.name, wo_eo3_dataset.type.name]
+        product=[wo_eo3_dataset.product.name, wo_eo3_dataset.product.name, wo_eo3_dataset.product.name]
     )
     assert len(datasets) == 1
     assert datasets[0].id == wo_eo3_dataset.id
@@ -414,7 +428,7 @@ def test_searches_only_type_eo3(index: Index,
 
     # One result in the product
     datasets = index.datasets.search_eager(
-        product=wo_eo3_dataset.type.name,
+        product=wo_eo3_dataset.product.name,
         platform='landsat-8'
     )
     assert len(datasets) == 1
@@ -455,7 +469,7 @@ def test_search_special_fields_eo3(index: Index,
                                    wo_eo3_dataset: Dataset) -> None:
     # 'product' is a special case
     datasets = index.datasets.search_eager(
-        product=ls8_eo3_dataset.type.name
+        product=ls8_eo3_dataset.product.name
     )
     assert len(datasets) == 1
     assert datasets[0].id == ls8_eo3_dataset.id
@@ -469,11 +483,11 @@ def test_search_special_fields_eo3(index: Index,
 
 
 def test_search_by_uri_eo3(index, ls8_eo3_dataset, ls8_eo3_dataset2, eo3_ls8_dataset_doc):
-    datasets = index.datasets.search_eager(product=ls8_eo3_dataset.type.name,
+    datasets = index.datasets.search_eager(product=ls8_eo3_dataset.product.name,
                                            uri=eo3_ls8_dataset_doc[1])
     assert len(datasets) == 1
 
-    datasets = index.datasets.search_eager(product=ls8_eo3_dataset.type.name,
+    datasets = index.datasets.search_eager(product=ls8_eo3_dataset.product.name,
                                            uri='file:///x/yz')
     assert len(datasets) == 0
 
@@ -482,7 +496,7 @@ def test_search_conflicting_types(index, ls8_eo3_dataset):
     # Should return no results.
     with pytest.raises(ValueError):
         index.datasets.search_eager(
-            product=ls8_eo3_dataset.type.name,
+            product=ls8_eo3_dataset.product.name,
             # The ls8 type is not of type storage_unit.
             metadata_type='storage_unit'
         )
@@ -498,7 +512,7 @@ def test_fetch_all_of_md_type(index: Index, ls8_eo3_dataset: Dataset) -> None:
     assert results[0].id == ls8_eo3_dataset.id
     # Get every dataset of the type.
     results = index.datasets.search_eager(
-        product=ls8_eo3_dataset.type.name
+        product=ls8_eo3_dataset.product.name
     )
     assert len(results) == 1
     assert results[0].id == ls8_eo3_dataset.id
@@ -514,7 +528,7 @@ def test_count_searches(index: Index,
                         ls8_eo3_dataset: Dataset) -> None:
     # One result in the telemetry type
     datasets = index.datasets.count(
-        product=ls8_eo3_dataset.type.name,
+        product=ls8_eo3_dataset.product.name,
         platform='landsat-8',
         instrument='OLI_TIRS',
     )
@@ -558,17 +572,17 @@ def test_count_by_product_searches_eo3(index: Index,
                                        wo_eo3_dataset: Dataset) -> None:
     # Two result in the ls8 type
     products = tuple(index.datasets.count_by_product(
-        product=ls8_eo3_dataset.type.name,
+        product=ls8_eo3_dataset.product.name,
         platform='landsat-8'
     ))
-    assert products == ((ls8_eo3_dataset.type, 2),)
+    assert products == ((ls8_eo3_dataset.product, 2),)
 
     # Two results in the metadata type
     products = tuple(index.datasets.count_by_product(
         metadata_type=ls8_eo3_dataset.metadata_type.name,
         platform='landsat-8',
     ))
-    assert products == ((ls8_eo3_dataset.type, 2),)
+    assert products == ((ls8_eo3_dataset.product, 2),)
 
     # No results when searching for a different dataset type.
     products = tuple(index.datasets.count_by_product(
@@ -581,7 +595,7 @@ def test_count_by_product_searches_eo3(index: Index,
     products = set(index.datasets.count_by_product(
         platform='landsat-8',
     ))
-    assert products == {(ls8_eo3_dataset.type, 2), (wo_eo3_dataset.type, 1)}
+    assert products == {(ls8_eo3_dataset.product, 2), (wo_eo3_dataset.product, 1)}
 
     # No results for different metadata type.
     products = tuple(index.datasets.count_by_product(
@@ -594,7 +608,7 @@ def test_count_time_groups(index: Index,
                            ls8_eo3_dataset: Dataset) -> None:
     timeline = list(index.datasets.count_product_through_time(
         '1 day',
-        product=ls8_eo3_dataset.type.name,
+        product=ls8_eo3_dataset.product.name,
         time=Range(
             datetime.datetime(2016, 5, 11, tzinfo=tz.tzutc()),
             datetime.datetime(2016, 5, 13, tzinfo=tz.tzutc())
@@ -627,7 +641,7 @@ def test_count_time_groups_cli(clirunner: Any,
         verbose_flag=''
     )
     expected_out = (
-        f'{ls8_eo3_dataset.type.name}\n'
+        f'{ls8_eo3_dataset.product.name}\n'
         '    2016-05-11: 0\n'
         '    2016-05-12: 1\n'
     )
@@ -703,7 +717,7 @@ def test_cli_info_eo3(index: Index,
     # Check indexed time separately, as we don't care what timezone it's displayed in.
     indexed_time = yaml_docs[0]['indexed']
     assert isinstance(indexed_time, datetime.datetime)
-    assert assume_utc(indexed_time) == assume_utc(ls8_eo3_dataset.indexed_time)
+    assert tz_as_utc(indexed_time) == tz_as_utc(ls8_eo3_dataset.indexed_time)
 
     # Request two, they should have separate yaml documents
     opts.append(str(ls8_eo3_dataset2.id))
@@ -739,20 +753,20 @@ def test_find_duplicates_eo3(index,
     # Specifying groups as fields:
     f = ls8_eo3_dataset.metadata_type.dataset_fields.get
     field_res = sorted(index.datasets.search_product_duplicates(
-        ls8_eo3_dataset.type,
+        ls8_eo3_dataset.product,
         f('region_code'), f('dataset_maturity')
     ))
     assert field_res == expected_ls8_path_row_duplicates
     # Field names as strings
     product_res = sorted(index.datasets.search_product_duplicates(
-        ls8_eo3_dataset.type,
+        ls8_eo3_dataset.product,
         'region_code', 'dataset_maturity'
     ))
     assert product_res == expected_ls8_path_row_duplicates
 
     # No WO duplicates: there's only one
     sat_res = sorted(index.datasets.search_product_duplicates(
-        wo_eo3_dataset.type,
+        wo_eo3_dataset.product,
         'region_code', 'dataset_maturity'
     ))
     assert sat_res == []
@@ -783,7 +797,7 @@ def test_csv_search_via_cli_eo3(clirunner: Any,
             _cli_csv_search(('datasets',) + args, clirunner)
 
     matches_both('lat in [-40, -10]')
-    matches_both('product=' + ls8_eo3_dataset.type.name)
+    matches_both('product=' + ls8_eo3_dataset.product.name)
 
     # Don't return on a mismatch
     matches_none('lat in [150, 160]')
